@@ -1,3 +1,5 @@
 #  Copyright (c) 2020 | KingKevin23 (@kingkevin023)
 
-import agspiel.api, agspiel.utils
\ No newline at end of file
+from . import api, utils
+
+__all__ = [api, utils]
\ No newline at end of file
